==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=da
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'icone_evolution_visites' => 'Udvikling i besøg <br />@visites@ besøg',
	'icone_repartition_actuelle' => 'Vis faktisk fordeling',
	'icone_repartition_visites' => 'Besøgsfordeling',
	'icone_statistiques_visites' => 'Besøgsstatistik',
	'info_affichier_visites_articles_plus_visites' => 'Vis besøg til <b>de mest besøgte artikler siden starten:</b>',
	'info_comment_lire_tableau' => 'Sådan læses grafen',
	'info_forum_statistiques' => 'Besøgsstatistik',
	'info_popularite_2' => 'webstedets polularitet:',
	'info_popularite_3' => 'polularitet: @popularite@; besøg: @visites@',
	'info_popularite_5' => 'polularitet:',
	'info_visites' => 'besøg:',
	'info_visites_plus_populaires' => 'Vis besøg til <b>de mest populære artikler</b> og til <b>de senest offentliggjorte artikler:</b>',
	'item_gerer_statistiques' => 'Dan statistik', # MODIF

	// O
	'onglet_origine_visites' => 'Besøgendes oprindelse',
	'onglet_repartition_debut' => 'fra begyndelsen',
	'onglet_repartition_lang' => 'efter sprog',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Artiklens rangering i popularitetslisten vises i marginen. Artiklens popularitet (et overslag over hvor mange daglige besøg den vil opnå, hvis det aktuelle trafikomfang opretholdes) og antallet af besøg, der er registreret siden begyndelsen, vises i den ballon, der kommer til syne når musen holdes over titlen.',
	'texte_signification' => 'Røde bjælker viser summer (totaler for underafsnit), 
		grønne bjælker viser antal besøg i hvert afsnit.',
	'titre_evolution_visite' => 'Udvikling i besøgstal',
	'titre_liens_entrants' => 'Dagens indkomne links',
	'titre_page_statistiques' => 'Statistik pr. afsnit',
	'titre_page_statistiques_visites' => 'Besøgsstatistik'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_da.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=da
// ** ne pas modifier le fichier **

return [

	// I
	'icone_evolution_visites' => 'Udvikling i besøg <br />@visites@ besøg',
	'icone_repartition_actuelle' => 'Vis faktisk fordeling',
	'icone_repartition_visites' => 'Besøgsfordeling',
	'icone_statistiques_visites' => 'Besøgsstatistik',
	'info_affichier_visites_articles_plus_visites' => 'Vis besøg til <b>de mest besøgte artikler siden starten:</b>',
	'info_comment_lire_tableau' => 'Sådan læses grafen',
	'info_forum_statistiques' => 'Besøgsstatistik',
	'info_popularite_2' => 'webstedets polularitet:',
	'info_popularite_3' => 'polularitet: @popularite@; besøg: @visites@',
	'info_popularite_5' => 'polularitet:',
	'info_visites' => 'besøg:',
	'info_visites_plus_populaires' => 'Vis besøg til <b>de mest populære artikler</b> og til <b>de senest offentliggjorte artikler:</b>',
	'item_gerer_statistiques' => 'Dan statistik', # MODIF

	// O
	'onglet_origine_visites' => 'Besøgendes oprindelse',
	'onglet_repartition_debut' => 'fra begyndelsen',
	'onglet_repartition_lang' => 'efter sprog',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Artiklens rangering i popularitetslisten vises i marginen. Artiklens popularitet (et overslag over hvor mange daglige besøg den vil opnå, hvis det aktuelle trafikomfang opretholdes) og antallet af besøg, der er registreret siden begyndelsen, vises i den ballon, der kommer til syne når musen holdes over titlen.',
	'texte_signification' => 'Røde bjælker viser summer (totaler for underafsnit), 
		grønne bjælker viser antal besøg i hvert afsnit.',
	'titre_evolution_visite' => 'Udvikling i besøgstal',
	'titre_liens_entrants' => 'Dagens indkomne links',
	'titre_page_statistiques' => 'Statistik pr. afsnit',
	'titre_page_statistiques_visites' => 'Besøgsstatistik',
];
